@@ -1,7 +1,5 @@
 
-import sys
 import os
-sys.path.append('.')
 
 from wsgi_intercept import httplib2_intercept
 import wsgi_intercept
