@@ -42,7 +42,7 @@ def instance(directory):
         raise IOError('Your chosen directory already exists. Choose a different name.')
 
     cfg = {
-        'system_plugins': ['tiddlywebwiki', 'status', 'differ'],
+        'system_plugins': ['tiddlywebwiki', 'tiddlywebplugins.status', 'differ'],
         'twanager_plugins': ['tiddlywebwiki']
     }
     create_instance(directory, config, defaults=cfg)
